@@ -66,7 +66,7 @@ use warnings FATAL => 'all';
 package HTML::Tested;
 use base 'Class::Accessor', 'Class::Data::Inheritable';
 use Carp;
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 __PACKAGE__->mk_classdata('Widgets_Map');
 
@@ -158,7 +158,8 @@ sub ht_convert_request_to_tree {
 }
 
 __PACKAGE__->register_tested_widget('value', 'HTML::Tested::Value');
-__PACKAGE__->register_tested_widget('marked_value', 'HTML::Tested::Value::Marked');
+__PACKAGE__->register_tested_widget('marked_value', 
+		'HTML::Tested::Value::Marked');
 __PACKAGE__->register_tested_widget('edit_box', 'HTML::Tested::Value::EditBox');
 __PACKAGE__->register_tested_widget(
 		'textarea', 'HTML::Tested::Value::TextArea');
@@ -168,6 +169,7 @@ __PACKAGE__->register_tested_widget(
 		'dropdown', 'HTML::Tested::Value::DropDown');
 __PACKAGE__->register_tested_widget(
 		'checkbox', 'HTML::Tested::Value::CheckBox');
+__PACKAGE__->register_tested_widget('link', 'HTML::Tested::Value::Link');
 
 __PACKAGE__->register_tested_widget('list', 'HTML::Tested::List');
 
